@@ -26,4 +26,4 @@
 #endif
 
 #define TEXT_DOMAIN		"gnucash"
-#define LOCALE_DIR		"/usr/local/share/locale"
+#define LOCALE_DIR		"/usr/share/locale"
