@@ -95,8 +95,6 @@
 (gw:wrap-as-wct ws '<gnc:id-type> "GNCIdType" "GNCIdTypeConst")
 (gw:wrap-as-wct ws '<gnc:Account*> "Account*" "const Account*")
 (gw:wrap-as-wct ws '<gnc:Account**> "Account**" "const Account**")
-(gw:wrap-as-wct ws '<gnc:InvAcct*> "InvAcct*" "const InvAcct*")
-(gw:wrap-as-wct ws '<gnc:AccInfo*> "AccInfo*" "const AccInfo*")
 (gw:wrap-as-wct ws '<gnc:AccountGroup*> "AccountGroup*" "const AccountGroup*")
 (gw:wrap-as-wct ws '<gnc:Book*> "GNCBook*" "const GNCBook*")
 (gw:wrap-as-wct ws '<gnc:Lot*> "GNCLot*" "const GNCLot*")
@@ -1933,13 +1931,13 @@ of having a parent transaction with which one is working...")
  "xaccQueryAddDateMatch"
  '((<gnc:Query*> q)
    (<gw:bool> use-start)
-   (<gw:int> st-year)
-   (<gw:int> st-mon)
    (<gw:int> st-day)
+   (<gw:int> st-mon)
+   (<gw:int> st-year)
    (<gw:bool> use-end)
-   (<gw:int> end-year)
-   (<gw:int> end-mon)
    (<gw:int> end-day)
+   (<gw:int> end-mon)
+   (<gw:int> end-year)
    (<gnc:query-op> how))
  "Match the transaction date.")
 
