@@ -21,14 +21,14 @@
  *                                                                  *
 \********************************************************************/
 
-#ifndef __KVP_FRAME_H__
-#define __KVP_FRAME_H__
+#ifndef KVP_FRAME_H
+#define KVP_FRAME_H
 
 #include <glib.h>
 
 #include "gnc-numeric.h"
 #include "guid.h"
-
+#include "date.h"
 
 /* a kvp_frame is a set of associations between character strings
  * (keys) and kvp_value structures.  A kvp_value is a union with
@@ -48,6 +48,7 @@ typedef enum {
   KVP_TYPE_NUMERIC,
   KVP_TYPE_STRING,
   KVP_TYPE_GUID,
+  KVP_TYPE_TIMESPEC,
   KVP_TYPE_BINARY, 
   KVP_TYPE_GLIST,
   KVP_TYPE_FRAME
@@ -86,7 +87,7 @@ kvp_value   * kvp_frame_get_slot(kvp_frame * frame,
                                  const char * key);
 
 /* The kvp_frame_set_slot_path() routines walk the hierarchy,
- * using the key falues to pick each branch.  When the terminal node
+ * using the key values to pick each branch.  When the terminal node
  * is reached, the value is copied into it.
  */
 void          kvp_frame_set_slot_path (kvp_frame *frame,
@@ -103,13 +104,13 @@ void          kvp_frame_set_slot_path_gslist (kvp_frame *frame,
  * The kvp_frame_get_frame_slash() routine takes a single string
  *    where the keys are separated by slashes; thus, for example:
  *    /this/is/a/valid/path  and///so//is////this/
- *    Multiple slashes are compresed. leading slash is optional.
+ *    Multiple slashes are compresed.  Leading slash is optional.
  *    The pointers . and .. are *not* followed/obeyed.  (This is 
  *    arguably a bug that needs fixing).
  *
  * 
  */
-kvp_frame    * kvp_frame_get_frame (kvp_frame *frame, ...);
+kvp_frame    * kvp_frame_get_frame (kvp_frame *frame, const char *,...);
 
 kvp_frame    * kvp_frame_get_frame_gslist (kvp_frame *frame,
                                            GSList *key_path);
@@ -117,7 +118,7 @@ kvp_frame    * kvp_frame_get_frame_gslist (kvp_frame *frame,
 kvp_frame    * kvp_frame_get_frame_slash (kvp_frame *frame,
                                           const char *path);
 
-/* The following routines return the value att the end of the
+/* The following routines return the value at the end of the
  * path, or NULL if any portion of the path doesn't exist.
  */
 kvp_value   * kvp_frame_get_slot_path (kvp_frame *frame,
@@ -131,24 +132,35 @@ gint          double_compare(double v1, double v2);
 
 void          kvp_value_delete(kvp_value * value);
 kvp_value   * kvp_value_copy(const kvp_value * value);
+/**
+ * Similar returns as strcmp.
+ **/
 gint          kvp_value_compare(const kvp_value *va, const kvp_value *vb);
 
 /* list convenience funcs. */
 gint        kvp_glist_compare(const GList * list1, const GList * list2);
 
+/* kvp_glist_copy() performs a deep copy: same as mapping 
+ *     kvp_value_copy() over the elements and then copying the spine. 
+ */
 GList     * kvp_glist_copy(const GList * list);
-            /* deep copy: same as mapping kvp_value_copy over the
-               elements and then copying the spine. */
-void        kvp_glist_delete(GList * list);
-            /* deep delete: same as mapping kvp_value_delete over the
-               elements and then deleting the GList. */
 
-/* value constructors (copying for pointer args) */
+/* kvp_glist_delete() performs a deep delete: same as mapping 
+ *    kvp_value_delete() over the elements and then deleting the GList. 
+ */
+void        kvp_glist_delete(GList * list);
+
+/* The following routines are constructors for kvp_value.
+ *    Those with pointer arguments copy in the value.
+ *    The *_nc() versions do *not* copy in thier values, 
+ *    but use them directly.
+ */
 kvp_value   * kvp_value_new_gint64(gint64 value);
 kvp_value   * kvp_value_new_double(double value);
 kvp_value   * kvp_value_new_gnc_numeric(gnc_numeric value);
 kvp_value   * kvp_value_new_string(const char * value);
 kvp_value   * kvp_value_new_guid(const GUID * guid);
+kvp_value   * kvp_value_new_timespec(Timespec timespec);
 kvp_value   * kvp_value_new_binary(const void * data, guint64 datasize);
 kvp_value   * kvp_value_new_glist(const GList * value);
 kvp_value   * kvp_value_new_frame(const kvp_frame * value);
@@ -157,8 +169,15 @@ kvp_value   * kvp_value_new_frame(const kvp_frame * value);
    values *must* have been allocated via glib allocators! (gnew, etc.) */
 kvp_value   * kvp_value_new_binary_nc(void * data, guint64 datasize);
 kvp_value   * kvp_value_new_glist_nc(GList *lst);
+kvp_value   * kvp_value_new_frame_nc(kvp_frame * value);
 
-/* value accessors (NON-copying for frames/lists/guids/binary) */
+/* Value accessors. Those for GUID, binary, GList, kvp_frame and
+  string are non-copying -- the caller can modify the value directly.
+
+  Note that the above non-copying list did not include the
+  get_string() function. But in fact that function has always been a
+  non-copying one -- therefore don't free the result unless you want
+  to delete the whole kvp_frame by yourself. */
 kvp_value_t kvp_value_get_type(const kvp_value * value);
 
 gint64      kvp_value_get_gint64(const kvp_value * value);
@@ -170,6 +189,7 @@ void        * kvp_value_get_binary(const kvp_value * value,
                                    guint64 * size_return); 
 GList       * kvp_value_get_glist(const kvp_value * value);
 kvp_frame   * kvp_value_get_frame(const kvp_value * value);
+Timespec    kvp_value_get_timespec(const kvp_value * value);
 
 gchar* kvp_value_to_string(const kvp_value *val);
 
