@@ -21,32 +21,15 @@
  * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
-#ifndef __DIALOG_FIND_TRANSACTIONS_H_
-#define __DIALOG_FIND_TRANSACTIONS_H_
+#ifndef DIALOG_FIND_TRANSACTIONS_H
+#define DIALOG_FIND_TRANSACTIONS_H
 
 #include <gnome.h>
 
-#include "MultiLedger.h"
+#include "gnc-ledger-display.h"
+#include "dialog-search.h"
 
-
-typedef struct _SelectDateDialog SelectDateDialog;
-typedef struct _FindTransactionsDialog FindTransactionsDialog;
-
-
-FindTransactionsDialog * 
-gnc_ui_find_transactions_dialog_create(xaccLedgerDisplay * ledger);
-
-void gnc_ui_find_transactions_dialog_destroy(FindTransactionsDialog * pcd);
-void gnc_ui_find_transactions_dialog_ok_cb(GtkButton * button,
-                                           gpointer  user_data);
-void gnc_ui_find_transactions_dialog_cancel_cb(GtkButton * button,
-                                               gpointer user_data);
-
-SelectDateDialog *
-gnc_ui_select_date_dialog_create(GtkWidget * w1, GtkWidget * w2, 
-                                 GtkWidget * w3, char * ymd_format);
-void gnc_ui_select_date_dialog_destroy(SelectDateDialog * sdd);
-void gnc_ui_select_date_cancel_cb(GtkWidget * w, gpointer user_data);
-void gnc_ui_select_date_ok_cb(GtkWidget * w, gpointer user_data);
+GNCSearchWindow *
+gnc_ui_find_transactions_dialog_create(GNCLedgerDisplay * ledger);
 
 #endif
