@@ -27,8 +27,19 @@
 #endif
 
 #include <gnome.h>
+#include <aqbanking/version.h>
 #include <aqbanking/account.h>
 #include <aqbanking/jobsingletransfer.h>
+#include <aqbanking/jobsingledebitnote.h>
+#if ((AQBANKING_VERSION_MAJOR > 1) || \
+     ((AQBANKING_VERSION_MAJOR == 1) && \
+      ((AQBANKING_VERSION_MINOR > 6) || \
+       ((AQBANKING_VERSION_MINOR == 6) && \
+        ((AQBANKING_VERSION_PATCHLEVEL > 0) || \
+	 (AQBANKING_VERSION_BUILD > 2))))))
+# include <aqbanking/jobinternaltransfer.h>
+#endif
+#include <iconv.h>
 
 #include "dialog-utils.h"
 #include "gnc-ui.h"
@@ -323,6 +334,7 @@ gnc_hbci_dialog_new (GtkWidget *parent,
        the labels accordingly. */
     switch (trans_type) {
     case SINGLE_TRANSFER:
+    case SINGLE_INTERNAL_TRANSFER:
       /* all labels are already set */
       break;
     case SINGLE_DEBITNOTE:
@@ -438,7 +450,20 @@ int gnc_hbci_dialog_run_until_ok(HBCITransDialog *td,
       printf("gnc_hbci_trans_dialog_enqueue: Oops, job not available. Aborting.\n");
       return -1;
     }
+#if ((AQBANKING_VERSION_MAJOR > 1) || \
+     ((AQBANKING_VERSION_MAJOR == 1) && \
+      ((AQBANKING_VERSION_MINOR > 0) || \
+       ((AQBANKING_VERSION_MINOR == 0) && \
+        (AQBANKING_VERSION_PATCHLEVEL > 6)))))
+    {
+      const AB_TRANSACTION_LIMITS *joblimits = AB_JobSingleTransfer_GetFieldLimits(job);
+      max_purpose_lines = (joblimits ?
+			   AB_TransactionLimits_GetMaxLinesPurpose (joblimits) :
+			   2);
+    }
+#else
     max_purpose_lines = AB_JobSingleTransfer_GetMaxPurposeLines(job);
+#endif
     /* these are the number of fields, 27 characters each. */
     AB_Job_free(job);
   }
@@ -492,6 +517,26 @@ int gnc_hbci_dialog_run_until_ok(HBCITransDialog *td,
       continue;
     } /* check Transaction_value */
 
+    {
+      char *purpose = gnc_hbci_getpurpose (td->hbci_trans);
+      if (strlen(purpose) == 0) {
+	gtk_widget_show_all (td->dialog); 
+	values_ok = !gnc_verify_dialog_parented
+	  (GTK_WIDGET (td->dialog),
+	   TRUE,
+	   "%s",
+	   _("You did not enter any transaction purpose. A purpose is \n"
+	     "required for an online transfer.\n"
+	     "\n"
+	     "Do you want to enter the job again?"));
+	if (values_ok) {
+	  AB_Transaction_free (td->hbci_trans);
+	  return -1;
+	}
+	continue;
+      } /* check Transaction_purpose */
+    }
+
     /* FIXME: If this is a direct debit, set the textkey/ "Textschluessel"/
        transactionCode according to some GUI selection here!! */
     /*if (td->trans_type == SINGLE_DEBITNOTE)
@@ -505,7 +550,6 @@ int gnc_hbci_dialog_run_until_ok(HBCITransDialog *td,
   return result;
 }
 
-
 /** Create a new AB_TRANSACTION, fill the values from the entry
     fields into it and return it. The caller must
     AB_TRANSACTION_free() it when finished. */
@@ -514,6 +558,15 @@ hbci_trans_fill_values(const AB_ACCOUNT *h_acc, HBCITransDialog *td)
 {
   /* Fill in the user-entered values */
   AB_TRANSACTION *trans = AB_Transaction_new();
+  gchar *tmpchar;
+
+  /* FIXME: The internal source encoding is hard-coded so far. This
+     needs to be fixed for the gnome2 version; the source encoding is
+     then probably utf-8 as well. iconv is also used in
+     gnc_AB_BANKING_interactors() in hbci-interaction.c. */
+  iconv_t gnc_iconv_handler =
+    iconv_open(gnc_hbci_AQBANKING_encoding(), gnc_hbci_book_encoding());
+  g_assert(gnc_iconv_handler != (iconv_t)(-1));
 	
   /* OpenHBCI newer than 0.9.8: use account's bankCode values
    * instead of the bank's ones since this is what some banks
@@ -532,19 +585,35 @@ hbci_trans_fill_values(const AB_ACCOUNT *h_acc, HBCITransDialog *td)
   /* printf("Got otherAccountId %s.\n",
      AB_Transaction_otherAccountId (trans)); */
   AB_Transaction_SetRemoteCountry (trans, "DE");
-  AB_Transaction_AddRemoteName
-    (trans, gtk_entry_get_text (GTK_ENTRY (td->recp_name_entry)), FALSE);
+
+  /* Convert the result of GTK_ENTRY into UTF-8 */
+  tmpchar = gnc_call_iconv(gnc_iconv_handler, 
+			   gtk_entry_get_text (GTK_ENTRY (td->recp_name_entry)));
+  AB_Transaction_AddRemoteName (trans, tmpchar, FALSE);
+  g_free (tmpchar);
 	
   /* The last argument means: If TRUE, then the string will be only be
      appended if it doesn't exist yet. */
-  AB_Transaction_AddPurpose
-    (trans, gtk_entry_get_text (GTK_ENTRY (td->purpose_entry)), FALSE);
-  AB_Transaction_AddPurpose
-    (trans, gtk_entry_get_text (GTK_ENTRY (td->purpose_cont_entry)), FALSE);
-  AB_Transaction_AddPurpose
-    (trans, gtk_entry_get_text (GTK_ENTRY (td->purpose_cont2_entry)), FALSE);
-  AB_Transaction_AddPurpose
-    (trans, gtk_entry_get_text (GTK_ENTRY (td->purpose_cont3_entry)), FALSE);
+  /* Convert the result of GTK_ENTRY into UTF-8 */
+  tmpchar = gnc_call_iconv(gnc_iconv_handler, 
+			   gtk_entry_get_text (GTK_ENTRY (td->purpose_entry)));
+  AB_Transaction_AddPurpose (trans, tmpchar, FALSE);
+  g_free (tmpchar);
+  tmpchar = gnc_call_iconv(gnc_iconv_handler, 
+			   gtk_entry_get_text (GTK_ENTRY (td->purpose_cont_entry)));
+  if (strlen(tmpchar) > 0)
+    AB_Transaction_AddPurpose (trans, tmpchar, FALSE);
+  g_free (tmpchar);
+  tmpchar = gnc_call_iconv(gnc_iconv_handler, 
+			   gtk_entry_get_text (GTK_ENTRY (td->purpose_cont2_entry)));
+  if (strlen(tmpchar) > 0)
+    AB_Transaction_AddPurpose (trans, tmpchar, FALSE);
+  g_free (tmpchar);
+  tmpchar = gnc_call_iconv(gnc_iconv_handler, 
+			   gtk_entry_get_text (GTK_ENTRY (td->purpose_cont3_entry)));
+  if (strlen(tmpchar) > 0)
+    AB_Transaction_AddPurpose (trans, tmpchar, FALSE);
+  g_free (tmpchar);
 	
   /* FIXME: Replace "EUR" by account-dependent string here. */
   AB_Transaction_SetValue 
@@ -563,6 +632,7 @@ hbci_trans_fill_values(const AB_ACCOUNT *h_acc, HBCITransDialog *td)
     AB_Transaction_SetTextKey (trans, 51);
   }
 
+  iconv_close(gnc_iconv_handler);
   return trans;
 }
 
@@ -624,15 +694,47 @@ gnc_hbci_trans_dialog_enqueue(HBCITransDialog *td, AB_BANKING *api,
   AB_JOB *job;
 
   /* Create a Do-Transaction (Transfer) job. */
-  job = AB_JobSingleTransfer_new(h_acc);
+  switch (trans_type) {
+  case SINGLE_DEBITNOTE:
+    job = AB_JobSingleDebitNote_new(h_acc);
+    break;
+  case SINGLE_INTERNAL_TRANSFER:
+#if ((AQBANKING_VERSION_MAJOR > 1) || \
+     ((AQBANKING_VERSION_MAJOR == 1) && \
+      ((AQBANKING_VERSION_MINOR > 6) || \
+       ((AQBANKING_VERSION_MINOR == 6) && \
+        ((AQBANKING_VERSION_PATCHLEVEL > 0) || \
+	 (AQBANKING_VERSION_BUILD > 2))))))
+    job = AB_JobInternalTransfer_new(h_acc);
+    break;
+#endif
+  default:
+  case SINGLE_TRANSFER:
+    job = AB_JobSingleTransfer_new(h_acc);
+  };
   if (AB_Job_CheckAvailability(job)) {
     printf("gnc_hbci_trans_dialog_enqueue: Oops, job not available. Aborting.\n");
     return NULL;
   }
-  AB_JobSingleTransfer_SetTransaction(job, td->hbci_trans);
 
-  /* Make really sure there is no other job in the queue */
-/*   HBCI_Outbox_removeByStatus (outbox, HBCI_JOB_STATUS_NONE); */
+  switch (trans_type) {
+  case SINGLE_DEBITNOTE:
+    AB_JobSingleDebitNote_SetTransaction(job, td->hbci_trans);
+    break;
+  case SINGLE_INTERNAL_TRANSFER:
+#if ((AQBANKING_VERSION_MAJOR > 1) || \
+     ((AQBANKING_VERSION_MAJOR == 1) && \
+      ((AQBANKING_VERSION_MINOR > 6) || \
+       ((AQBANKING_VERSION_MINOR == 6) && \
+        ((AQBANKING_VERSION_PATCHLEVEL > 0) || \
+	 (AQBANKING_VERSION_BUILD > 2))))))
+    AB_JobInternalTransfer_SetTransaction(job, td->hbci_trans);
+    break;
+#endif
+  default:
+  case SINGLE_TRANSFER:
+    AB_JobSingleTransfer_SetTransaction(job, td->hbci_trans);
+  };
 
   /* Add job to queue */
   AB_Banking_EnqueueJob(api, job);
