@@ -102,9 +102,7 @@ gnc_hbci_getbalance (GtkWidget *parent, Account *gnc_acc)
     if (!gnc_AB_BANKING_execute (parent, api, job, interactor)) {
 
       /* AB_BANKING_executeOutbox failed. */
-      AB_Banking_DequeueJob(api, job);
-      AB_Banking_DelFinishedJob(api, job);
-      AB_Banking_DelPendingJob(api, job);
+      gnc_hbci_cleanup_job(api, job);
       /* FIXME: free unneeded data */
       return;
     }
@@ -117,9 +115,7 @@ gnc_hbci_getbalance (GtkWidget *parent, Account *gnc_acc)
 				job);
 
     /* Clean up after ourselves. */
-    AB_Banking_DequeueJob(api, job);
-    AB_Banking_DelFinishedJob(api, job);
-    AB_Banking_DelPendingJob(api, job);
+    gnc_hbci_cleanup_job(api, job);
     gnc_AB_BANKING_fini (api);
     GNCInteractor_hide (interactor);
   }
@@ -198,9 +194,10 @@ gnc_hbci_getbalance_finish (GtkWidget *parent,
   const AB_ACCOUNT_STATUS *response;
   const AB_BALANCE *noted_grp, *booked_grp;
   const AB_VALUE *booked_val, *noted_val;
-  time_t booked_tt;
+  time_t booked_tt=0;
   gboolean dialogres;
   double booked_value, noted_value;
+  gnc_numeric value;
 
   response = AB_JobGetBalance_GetAccountStatus((AB_JOB*)job);
   if (!response) {
@@ -212,8 +209,12 @@ gnc_hbci_getbalance_finish (GtkWidget *parent,
   booked_grp = AB_AccountStatus_GetBookedBalance(response);
 
   if (booked_grp) {
+    const GWEN_TIME *ti;
+
+    ti=AB_Balance_GetTime(booked_grp);
+    if (ti)
+      booked_tt = GWEN_Time_toTime_t (ti);
     booked_val = AB_Balance_GetValue(booked_grp);
-    booked_tt = GWEN_Time_toTime_t (AB_Balance_GetTime(booked_grp));
     if (booked_val)
       booked_value = AB_Value_GetValue (booked_val);
     else {
@@ -242,6 +243,9 @@ gnc_hbci_getbalance_finish (GtkWidget *parent,
     noted_val = NULL;
   }
 
+  value = double_to_gnc_numeric (booked_value,
+				 xaccAccountGetCommoditySCU(gnc_acc),
+				 GNC_RND_ROUND);
   if ((noted_value == 0.0) && (booked_value == 0.0))
     {
       gnome_ok_dialog_parented 
@@ -260,6 +264,8 @@ gnc_hbci_getbalance_finish (GtkWidget *parent,
     }
   else
     {
+      gnc_numeric reconc_balance = xaccAccountGetReconciledBalance (gnc_acc);
+
       char *booked_str = gnc_AB_VALUE_toReadableString (booked_val);
       char *message1 = g_strdup_printf
 	(
@@ -273,14 +279,24 @@ gnc_hbci_getbalance_finish (GtkWidget *parent,
 	 (_("For your information: This account also \n"
 	    "has a noted balance of %s\n"),
 	  noted_val));
-      const char *message3 = _("Reconcile account now?");
 
-      dialogres = gnc_verify_dialog_parented
-	(parent, 
-	 TRUE,
-	 "%s%s\n%s",
-	 message1, message2, message3);
+      if (gnc_numeric_equal(value, reconc_balance)) {
+	const char *message3 = _("The booked balance is identical to the current \n"
+				 "reconciled balance of the account.");
+	char *msg = g_strdup_printf ("%s%s\n%s", message1, message2, message3);
+	gnome_ok_dialog_parented (msg, GTK_WINDOW (parent));
+	g_free (msg);
+	dialogres = FALSE;
 
+      } else {
+	const char *message3 = _("Reconcile account now?");
+
+	dialogres = gnc_verify_dialog_parented
+	  (parent, 
+	   TRUE,
+	   "%s%s\n%s",
+	   message1, message2, message3);
+      }
       g_free (message1);
       g_free (message2);
       free (booked_str);
@@ -289,10 +305,6 @@ gnc_hbci_getbalance_finish (GtkWidget *parent,
       
   if (dialogres) 
     {
-      gnc_numeric value =
-	double_to_gnc_numeric (booked_value,
-			       xaccAccountGetCommoditySCU(gnc_acc),
-			       GNC_RND_ROUND);
       recnWindowWithBalance (parent, 
 			     gnc_acc, 
 			     value,
