@@ -25,7 +25,10 @@
 
 #include <gnome.h>
 #include <errno.h>
+#include <iconv.h>
+#include <langinfo.h>
 #include <gwenhywfar/directory.h>
+#include <gwenhywfar/logger.h>
 
 #include "gnc-ui.h"
 #include "gnc-hbci-kvp.h"
@@ -134,7 +137,7 @@ gnc_hbci_get_hbci_acc (const AB_BANKING *api, Account *gnc_acc)
 
     if (!hbci_acc && bankcode && (strlen(bankcode)>0) &&
 	accountid && (strlen(accountid) > 0)) {
-      printf("gnc_hbci_get_hbci_acc: No AB_ACCOUNT found for UID %d, trying bank code\n", account_uid);
+      /* printf("gnc_hbci_get_hbci_acc: No AB_ACCOUNT found for UID %d, trying bank code\n", account_uid); */
       hbci_acc = AB_Banking_GetAccountByCodeAndNumber(api, bankcode, accountid);
     }
     /*printf("gnc_hbci_get_hbci_acc: return HBCI_Account %p\n", hbci_acc);*/
@@ -187,6 +190,7 @@ gnc_hbci_debug_outboxjob (AB_JOB *job, gboolean verbose)
 /*   list_int *list; */
 /*   const char *msg; */
   int cause = 0;
+  AB_JOB_STATUS jobstatus;
   
   g_assert (job);
 /*   if (AB_JOB_status (job) != HBCI_JOB_STATUS_DONE) */
@@ -195,12 +199,23 @@ gnc_hbci_debug_outboxjob (AB_JOB *job, gboolean verbose)
 /*     return; */
 
   if (verbose) {
-    printf("OutboxJob status: %s", AB_Job_Status2Char(AB_Job_GetStatus(job)));
+    printf("gnc_hbci_debug_outboxjob: Job status: %s", AB_Job_Status2Char(AB_Job_GetStatus(job)));
 
     printf(", result: %s", AB_Job_GetResultText(job));
     printf("\n");
   }
 
+  jobstatus = AB_Job_GetStatus (job);
+  if (jobstatus == AB_Job_StatusError) {
+    if (!verbose)
+      printf("gnc_hbci_debug_outboxjob: Job %s had an error: %s\n",
+	     AB_Job_Type2Char(AB_Job_GetType(job)),
+	     AB_Job_GetResultText(job));
+    cause = 9000;
+  } else {
+    cause = 0;
+  }
+
 #if 0  
   list = AB_JOB_resultCodes (job);
   if (list_int_size (list) > 0) {
@@ -239,6 +254,18 @@ gnc_hbci_debug_outboxjob (AB_JOB *job, gboolean verbose)
   return cause;
 }
 
+void
+gnc_hbci_cleanup_job(AB_BANKING *api, AB_JOB *job)
+{
+  if (AB_Job_GetStatus(job) == AB_Job_StatusFinished) {
+    AB_Banking_DelFinishedJob(api, job);
+  } else if (AB_Job_GetStatus(job) == AB_Job_StatusPending) {
+    AB_Banking_DelPendingJob(api, job);
+  }
+  /* Martin assured me that there will be no job in the queue after
+     ExecuteQueue, so we don't need to remove it from the queue. */
+}
+
 
 gboolean
 gnc_hbci_Error_retry (GtkWidget *parent, int error, 
@@ -406,17 +433,23 @@ gnc_AB_BANKING_execute (GtkWidget *parent, AB_BANKING *api,
 {
   int err;
   int resultcode;
+  int be_verbose = FALSE;
 	  
   if (inter)
     GNCInteractor_show (inter);
 
   if (gnc_lookup_boolean_option("_+Advanced", 
 				"HBCI Verbose Debug Messages", FALSE)) {
-/*     GWEN_Logger_SetLevel(0, GWEN_LoggerLevelDebug); */
-/*     HBCI_Hbci_setDebugLevel (4); */
+    GWEN_Logger_SetLevel(GWEN_LOGDOMAIN, GWEN_LoggerLevelNotice);
+    GWEN_Logger_SetLevel(AQBANKING_LOGDOMAIN, GWEN_LoggerLevelInfo);
+    GWEN_Logger_SetLevel("aqhbci", GWEN_LoggerLevelInfo);
+    be_verbose = TRUE;
+  }
+  else {
+    GWEN_Logger_SetLevel(GWEN_LOGDOMAIN, GWEN_LoggerLevelError);
+    GWEN_Logger_SetLevel(AQBANKING_LOGDOMAIN, GWEN_LoggerLevelError);
+    GWEN_Logger_SetLevel("aqhbci", GWEN_LoggerLevelError);
   }
-/*   else */
-/*     HBCI_Hbci_setDebugLevel (0); */
 
   do {
     if (inter) {
@@ -436,7 +469,7 @@ gnc_AB_BANKING_execute (GtkWidget *parent, AB_BANKING *api,
     
   } while (gnc_hbci_Error_retry (parent, err, inter));
   
-  resultcode = gnc_hbci_debug_outboxjob (job, FALSE);
+  resultcode = gnc_hbci_debug_outboxjob (job, be_verbose);
   if (!hbci_Error_isOk(err)) {
 /*     char *errstr =  */
 /*       g_strdup_printf("gnc_AB_BANKING_execute: Error at executeQueue: %s", */
@@ -463,16 +496,22 @@ gnc_AB_BANKING_execute (GtkWidget *parent, AB_BANKING *api,
   }
 }
 
+struct cb_struct {
+  gchar **result;
+  iconv_t gnc_iconv_handler;
+};
+
 /* Needed for the gnc_hbci_descr_tognc and gnc_hbci_memo_tognc. */
 static void *gnc_list_string_cb (const char *string, void *user_data)
 {
-  gchar **res = user_data;
+  struct cb_struct *u = user_data;
+  gchar **res = u->result;
   gchar *tmp1, *tmp2;
 
   if (!string) return NULL;
-  tmp1 = g_strdup (string);
-  g_strstrip (tmp1);
+  tmp1 = gnc_call_iconv(u->gnc_iconv_handler, string);
 
+  g_strstrip (tmp1);
   if (strlen (tmp1) > 0) {
     if (*res != NULL) {
       /* The " " is the separating string in between each two strings. */
@@ -494,44 +533,68 @@ static void *gnc_list_string_cb (const char *string, void *user_data)
 char *gnc_hbci_descr_tognc (const AB_TRANSACTION *h_trans)
 {
   /* Description */
-  char *h_descr = NULL;
+  char *h_descr = gnc_hbci_getpurpose (h_trans);
   char *othername = NULL;
   char *g_descr;
-  const GWEN_STRINGLIST *h_purpose = AB_Transaction_GetPurpose (h_trans);
   const GWEN_STRINGLIST *h_remotename = AB_Transaction_GetRemoteName (h_trans);
+  struct cb_struct cb_object;
 
-  /* Don't use list_string_concat_delim here since we need to
-     g_strstrip every single element of the string list, which is
-     only done in our callback gnc_list_string_cb. The separator is
-     also set there. */
-  if (h_purpose)
-    GWEN_StringList_ForEach (h_purpose,
-			     &gnc_list_string_cb,
-			     &h_descr);
+  cb_object.gnc_iconv_handler = 
+    iconv_open(gnc_hbci_book_encoding(), gnc_hbci_AQBANKING_encoding());
+  g_assert(cb_object.gnc_iconv_handler != (iconv_t)(-1));
+
+  /* Get othername */
+  cb_object.result = &othername;
   if (h_remotename)
     GWEN_StringList_ForEach (h_remotename,
 			     &gnc_list_string_cb,
-			     &othername);
+			     &cb_object);
   /*DEBUG("HBCI Description '%s'", h_descr);*/
 
   if (othername && (strlen (othername) > 0))
     g_descr = 
-      ((h_descr && (strlen (h_descr) > 0)) ?
+      ((strlen (h_descr) > 0) ?
        g_strdup_printf ("%s; %s", 
 			h_descr,
 			othername) :
        g_strdup (othername));
   else
     g_descr = 
-      ((h_descr && (strlen (h_descr) > 0)) ?
+      ((strlen (h_descr) > 0) ?
        g_strdup (h_descr) : 
        g_strdup (_("Unspecified")));
 
+  iconv_close(cb_object.gnc_iconv_handler);
   free (h_descr);
   free (othername);
   return g_descr;
 }
 
+char *gnc_hbci_getpurpose (const AB_TRANSACTION *h_trans)
+{
+  /* Description */
+  char *h_descr = NULL;
+  char *g_descr;
+  const GWEN_STRINGLIST *h_purpose = AB_Transaction_GetPurpose (h_trans);
+  struct cb_struct cb_object;
+
+  cb_object.gnc_iconv_handler = 
+    iconv_open(gnc_hbci_book_encoding(), gnc_hbci_AQBANKING_encoding());
+  g_assert(cb_object.gnc_iconv_handler != (iconv_t)(-1));
+
+  cb_object.result = &h_descr;
+  if (h_purpose)
+    GWEN_StringList_ForEach (h_purpose,
+			     &gnc_list_string_cb,
+			     &cb_object);
+
+  g_descr = g_strdup (h_descr ? h_descr : "");
+
+  iconv_close(cb_object.gnc_iconv_handler);
+  free (h_descr);
+  return g_descr;
+}
+
 char *gnc_hbci_memo_tognc (const AB_TRANSACTION *h_trans)
 {
   /* Memo in the Split. HBCI's transactionText contains strings like
@@ -834,3 +897,36 @@ char *gnc_AB_VALUE_toReadableString(const AB_VALUE *v)
     sprintf(tmp, "%.2f", 0.0);
   return g_strdup(tmp);
 }
+
+/* Returns a newly allocated gchar, converted according to the given
+   handler */
+gchar *gnc_call_iconv(iconv_t handler, const char* input)
+{
+  char *inbuffer = (char*)input;
+  char *outbuffer, *outbufferstart;
+  int inbytes, outbytes;
+
+  inbytes = strlen(inbuffer);
+  outbytes = inbytes + 2;
+  outbufferstart = g_strndup(inbuffer, outbytes);
+  outbuffer = outbufferstart;
+  iconv(handler, &inbuffer, &inbytes, &outbuffer, &outbytes);
+  if (outbytes > 0) 
+    *outbuffer = '\0';
+  return outbufferstart;
+}
+
+const char *gnc_hbci_book_encoding()
+{
+#if HAVE_LANGINFO_CODESET
+  char* encoding = nl_langinfo(CODESET);
+#else
+  char* encoding = "ISO8859-15";
+#endif
+  return encoding;
+}
+
+const char *gnc_hbci_AQBANKING_encoding()
+{
+  return "UTF-8";
+}
