@@ -106,7 +106,7 @@ struct _matchinfo
 {
   Transaction * trans;
   Split * split;
-  //GNC_match_probability probability;
+  /*GNC_match_probability probability;*/
   gint probability;
 };
 
@@ -242,8 +242,8 @@ void gnc_import_TransInfo_delete (GNCImportTransInfo *info)
 {
   if (info) {
     g_list_free (info->match_list);
-    /*If the transaction is still open, it must be destroyed*/
-    if(xaccTransIsOpen(info->trans)==TRUE)
+    /*If the transaction exists and is still open, it must be destroyed*/
+    if(info->trans && xaccTransIsOpen(info->trans))
       {
 	xaccTransDestroy(info->trans);
 	xaccTransCommitEdit(info->trans);
@@ -616,11 +616,8 @@ static void split_find_match (GNCImportTransInfo * trans_info,
 	{
 	  /* If a transaction's amount doesn't match within the
 	     threshold, it's very unlikely to be the same transaction
-	     so we give it an extra -5 penality. Changed 2004-11-27:
-	     The penalty is so high that we can forget about this
-	     split anyway and skip the rest of the tests. */
-	  return;
-	  /* prob = prob-5; */
+	     so we give it an extra -5 penality */
+	  prob = prob-5;
 	  /* DEBUG("heuristics:  probability - 1 (amount)"); */
 	}
       
@@ -648,12 +645,13 @@ static void split_find_match (GNCImportTransInfo * trans_info,
       else if (datediff_day > MATCH_DATE_NOT_THRESHOLD)
 	{
 	  /* Extra penalty if that split lies awfully far away from
-	     the given one. Changed 2004-11-27: The penalty is so high
-	     that we can forget about this split anyway and skip the
-	     rest of the tests. */
-	  return;
-	  /* prob = prob-5; */
+	     the given one. */
+	  prob = prob-5;
 	  /*DEBUG("heuristics:  probability - 5 (date)"); */
+	  /* Changed 2005-02-21: Revert the hard-limiting behaviour
+	     back to the previous large penalty. (Changed 2004-11-27:
+	     The penalty is so high that we can forget about this
+	     split anyway and skip the rest of the tests.) */
 	}
       
       /* Check number heuristics */  
@@ -768,7 +766,8 @@ static void split_find_match (GNCImportTransInfo * trans_info,
    transaction, and find all matching splits there. */
 void gnc_import_find_split_matches(GNCImportTransInfo *trans_info,
 				   gint process_threshold, 
-				   double fuzzy_amount_difference)
+				   double fuzzy_amount_difference,
+				   gint match_date_hardlimit)
 {
   GList * list_element;
   Query *query = xaccMallocQuery();
@@ -790,8 +789,8 @@ void gnc_import_find_split_matches(GNCImportTransInfo *trans_info,
     xaccQueryAddSingleAccountMatch (query, importaccount,			    
 				    QUERY_AND);
     xaccQueryAddDateMatchTT (query,
-			     TRUE, download_time - MATCH_DATE_NOT_THRESHOLD*86400/2,
-			     TRUE, download_time + MATCH_DATE_NOT_THRESHOLD*86400/2,
+			     TRUE, download_time - match_date_hardlimit*86400,
+			     TRUE, download_time + match_date_hardlimit*86400,
 			     QUERY_AND);
     list_element = xaccQueryGetSplits (query);
     /* Sigh. Doesnt help too much. We still create and run one query
@@ -937,6 +936,8 @@ gnc_import_process_trans_clist (GtkCList *clist,
 	      xaccTransDestroy(trans_info->trans);
 	      /*DEBUG("CommitEdit trans")*/
 	      xaccTransCommitEdit(trans_info->trans);
+	      /* Very important: Make sure the freed transaction is not freed again! */
+	      trans_info->trans = NULL;
 	    }
 	  break;
 	case GNCImport_EDIT:
@@ -984,7 +985,7 @@ static gboolean check_trans_online_id(Transaction *trans1, void *user_data)
     }
   else
     {
-      //printf("test_trans_online_id(): Duplicate found\n");
+      /*printf("test_trans_online_id(): Duplicate found\n");*/
       return FALSE;
     }
 }
@@ -1072,7 +1073,8 @@ gnc_import_TransInfo_init_matches (GNCImportTransInfo *trans_info,
   /* Find all split matches in originating account. */
   gnc_import_find_split_matches(trans_info,  
 				gnc_import_Settings_get_display_threshold (settings),
-				gnc_import_Settings_get_fuzzy_amount (settings));
+				gnc_import_Settings_get_fuzzy_amount (settings),
+				gnc_import_Settings_get_match_date_hardlimit (settings));
   
   if (trans_info->match_list != NULL) 
     {
